| Title: | Calculation of the Surface Temperature (Ts) from Geospatial Raster Data |
|---|---|
| Description: | Provides functions to calculate the Surface Temperature (Ts) from geospatial raster data. These functions use albedo, Normalized Difference Vegetation Index (NDVI), and air temperature (Ta) to estimate Ts, facilitating hydrological, ecological, and remote sensing analyses. |
| Authors: | Gaelle Hamelin [aut, cre] (ORCID: <https://orcid.org/0009-0007-2148-7937>) |
| Maintainer: | Gaelle Hamelin <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.1 |
| Built: | 2026-05-19 05:54:06 UTC |
| Source: | https://github.com/cran/Ts |
This function calculates the surface temperature (Ts) from three rasters: albedo, NDVI, and air temperature (Ta). The resulting Ts raster will have the same unit as Ta.
calculate_Ts(albedo, ndvi, Ta, output_path = NULL, verbose = FALSE)calculate_Ts(albedo, ndvi, Ta, output_path = NULL, verbose = FALSE)
albedo |
RasterLayer/SpatRaster of albedo values |
ndvi |
RasterLayer/SpatRaster of NDVI values |
Ta |
RasterLayer/SpatRaster of air temperature (Ta) in Kelvin |
output_path |
File path to save the Ts raster (optional) |
verbose |
Logical; if TRUE, prints information about dry/wet edges, T_min/T_max, and unit info. Default is TRUE. |
SpatRaster of surface temperature (Ts) in the same unit as Ta
library(terra) albedo_raster <- rast(system.file("extdata", "albedo_mini.tif", package = "Ts")) Ta_raster <- rast(system.file("extdata", "Ta_mini.tif", package = "Ts")) ndvi_raster <- rast(system.file("extdata", "ndvi_mini.tif", package = "Ts")) output_path <- tempfile(fileext = ".tif") calculate_Ts( albedo = albedo_raster, Ta = Ta_raster, ndvi = ndvi_raster, output_path = output_path, verbose = TRUE ) print(output_path)library(terra) albedo_raster <- rast(system.file("extdata", "albedo_mini.tif", package = "Ts")) Ta_raster <- rast(system.file("extdata", "Ta_mini.tif", package = "Ts")) ndvi_raster <- rast(system.file("extdata", "ndvi_mini.tif", package = "Ts")) output_path <- tempfile(fileext = ".tif") calculate_Ts( albedo = albedo_raster, Ta = Ta_raster, ndvi = ndvi_raster, output_path = output_path, verbose = TRUE ) print(output_path)