The hardware and bandwidth for this mirror is donated by METANET, the Webhosting and Full Service-Cloud Provider.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]metanet.ch.

Type: Package
Title: Calculation of the Surface Temperature (Ts) from Geospatial Raster Data
Version: 1.0.1
Date: 2026-02-13
Description: Provides functions to calculate the Surface Temperature (Ts) from geospatial raster data. These functions use albedo, Normalized Difference Vegetation Index (NDVI), and air temperature (Ta) to estimate Ts, facilitating hydrological, ecological, and remote sensing analyses.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: stats, terra
Suggests: testthat (≥ 3.0.0)
NeedsCompilation: no
Packaged: 2026-02-13 13:47:59 UTC; hamelin
Author: Gaelle Hamelin ORCID iD [aut, cre]
Maintainer: Gaelle Hamelin <gaelle.hamelin@institut-agro.fr>
Repository: CRAN
Date/Publication: 2026-02-17 22:20:09 UTC

Calculate the Surface Temperature (Ts)

Description

This function calculates the surface temperature (Ts) from three rasters: albedo, NDVI, and air temperature (Ta). The resulting Ts raster will have the same unit as Ta.

Usage

calculate_Ts(albedo, ndvi, Ta, output_path = NULL, verbose = FALSE)

Arguments

albedo

RasterLayer/SpatRaster of albedo values

ndvi

RasterLayer/SpatRaster of NDVI values

Ta

RasterLayer/SpatRaster of air temperature (Ta) in Kelvin

output_path

File path to save the Ts raster (optional)

verbose

Logical; if TRUE, prints information about dry/wet edges, T_min/T_max, and unit info. Default is TRUE.

Value

SpatRaster of surface temperature (Ts) in the same unit as Ta

Examples

library(terra)

albedo_raster <- rast(system.file("extdata", "albedo_mini.tif", package = "Ts"))
Ta_raster     <- rast(system.file("extdata", "Ta_mini.tif", package = "Ts"))
ndvi_raster   <- rast(system.file("extdata", "ndvi_mini.tif", package = "Ts"))

output_path <- tempfile(fileext = ".tif")

calculate_Ts(
  albedo = albedo_raster,
  Ta     = Ta_raster,
  ndvi   = ndvi_raster,
  output_path = output_path,
  verbose = TRUE
)

print(output_path)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.